Dear {{ user.username }},

Someone asked for password reset for email {{ email }}. 

Follow the link below to change your password:
{{ protocol}}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}

Thanks and regards,
{{ site_name }}