{% extends "base_extra.html" %}
{% block title %}Password Reset{% endblock %}
{% load content_widgets %}

{% block content %}
<div class="card card-outline card-primary">
    <div class="card-header text-center">
        {% logo False %}
    </div>
    <div class="card-body">
        <p>Forgotten your password? Enter your email address below, and we’ll email instructions for setting a new one.</p>
        <form method="post">{% csrf_token %}
            <input type="hidden" name="next" value="{{ next }}">
            <div class="input-group mb-3">
                <input name="email" type="text" class="form-control {% if form.email.errors %}is-invalid{% endif %}" placeholder="Email">
                <div class="input-group-append">
                    <div class="input-group-text">
                        <span class="fas fa-envelope"></span>
                    </div>
                </div>
            </div>
            {{ form.email.errors }}
            <div class="row">
                <div class="col-lg-12">
                    <button type="submit" class="btn btn-primary btn-block">Reset my password</button>
                </div>
            </div>
        </form>
    </div>
</div>
{% endblock %}