{% extends "base_extra.html" %}
{% block title %}Password Reset{% endblock %}
{% load content_widgets %}

{% block content %}
<div class="card card-outline card-primary">
    <div class="card-header text-center">
        {% logo False %}
    </div>
    <div class="card-body">
        We’ve emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.
    </div>
</div>
{% endblock %}