{% extends "base_extra.html" %}
{% block title %}Password Reset{% endblock %}
{% load content_widgets %}

{% block content %}
<div class="card card-outline card-primary">
    <div class="card-header text-center">
        {% logo False %}
    </div>
    <div class="card-body">
        Your password has been set. You may go ahead and log in now.
        <div class="row">
            <div class="col-lg-12">
                <a class="btn btn-primary btn-block" href="{{ login_url }}">Sign In</a>
            </div>
        </div>
    </div>
</div>
{% endblock %}