{% extends "base.html" %}
{% block title %}Password Cjanged Successfully{% endblock %}

{% block content_header %}
<div class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1 class="m-0">Success</h1>
        </div>
        <div class="col-sm-6">
          <ol class="breadcrumb float-sm-right">
            <li class="breadcrumb-item"><a href="#">Home</a></li>
            <li class="breadcrumb-item active">Success</li>
          </ol>
        </div>
      </div>
    </div>
</div>
{% endblock %}

{% block content %}
<div class="row">
    <div class="col-lg-12">
        <div class="card">
            <div class="card-body">
              <h5 class="card-title">Your password changed successfully</h5>
              <p class="card-text"></p>
            </div>
        </div>
    </div>
</div>
{% endblock %}