{% extends "base.html" %}
{% block title %}Profile{% endblock %}

{% block content_header %}
<div class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1 class="m-0">Profile</h1>
        </div>
        <div class="col-sm-6">
          <ol class="breadcrumb float-sm-right">
            <li class="breadcrumb-item"><a href="/">Home</a></li>
            <li class="breadcrumb-item active">Profile</li>
          </ol>
        </div>
      </div>
    </div>
</div>
{% endblock %}

{% block content %}
<div class="row">
    <div class="col-lg-6">
        <div class="card">
            <div class="card-body">
              <h5 class="card-title">Welcome {{ user.username }}</h5>
              <p class="card-text">
                In this profile you will be able to see all the content created by you.
              </p>
            </div>
        </div>
    </div>
</div>
{% endblock %}

{% block content_help %}
<aside class="control-sidebar control-sidebar-dark">
  <div class="p-3">
    <h5>Title</h5>
    <p>Sidebar content</p>
  </div>
</aside>
{% endblock %}