body {font-family: 'Ubuntu', sans-serif; font-size: 15px;}
.card-title{font-weight: bold;}
form label{font-size: inherit; padding: 0px !important;}
form input{height: fit-content; border: 1px solid black;}
.form-row{margin-left: 0px; margin-right: 0px;}
.help ul li{color: rgb(148, 16, 16);}
.errorlist, .help{color: rgb(148, 16, 16); font-size: 11px; margin-bottom: 10px; padding-left: 0px !important; list-style-type: none;}
.errornote{color: rgb(148, 16, 16);}